##  Adding a Dashboard to a Collection
Collections enable you to arrange and categorize your dashboards, reports, and diagrams into custom groups defined by the workspace admin. For more information, see [Collections](https://help.sap.com/docs/leanix/ea/collections?locale=en-US&state=PRODUCTION&version=CLOUD "Use collections to arrange dashboards, reports, and diagrams into custom groups.").
As an admin, you can add dashboards (except for predefined ones) to collections to arrange them into groups by relevant topics. Collections appear on the left-side navigation pane and are arranged into collection groups. If a collection doesn’t contain any dashboards, it doesn’t appear on the left-side navigation pane.
To add a dashboard to a collection, on the dashboard preview, click the three-dot icon > Add to collection, then select a collection. You can add a dashboard to multiple collections.
![Adding a Dashboard to a Collection](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27557fc97a44101499e893665d7873c5_LowRes.png)
Adding a Dashboard to a Collection
To remove a dashboard from a collection, navigate to the collection from the left-side pane, click the three-dot icon on the dashboard preview, then select Remove from [Collection].
